@@ -15,6 +15,8 @@ from awsfile_helper.svc import DownloadFromS3
 from awsfile_helper.svc import CreateBucketFolder
 from awsfile_helper.svc import FindFileByVersion
 from awsfile_helper.svc import UploadImageFiles
+from awsfile_helper.svc import InvokeTextractAPI
+from awsfile_helper.svc import InvokeRekognitionLabeler
 
 
 class AwsAPI(BaseObject):
@@ -43,6 +45,13 @@ class AwsAPI(BaseObject):
             17-Nov-2022
             craigtrim@gmail.com
             *   add additional logging statements
+        Updated:
+            13-Jan-2023
+            craigtrim@gmail.com
+            *   add API functions (create-folder, upload-images)
+                https://github.com/craigtrim/awsfile-helper/issues/5
+            *   add API functions (rekognition, textract)
+                https://github.com/craigtrim/awsfile-helper/issues/7
 
         Args:
             aws_access_key (str, Optional): Encrypted AWS Access Key
@@ -53,6 +62,8 @@ class AwsAPI(BaseObject):
                 it must be encrypted within the environment as AWS_SECRET_KEY
         """
         BaseObject.__init__(self, __name__)
+        self._aws_access_key = aws_access_key
+        self._aws_secret_key = aws_secret_key
 
         self._s3_resource = ConnectToS3(  # S3 Resource ...
             aws_access_key=aws_access_key,
@@ -221,3 +232,39 @@ class AwsAPI(BaseObject):
         self._upload_images(bucket_name=bucket_name,
                             folder_name=folder_name,
                             file_paths=file_paths)
+
+    def rekognition(self,
+                    input_directory: str,
+                    output_directory: str) -> None:
+        """ Call the AWS Rekognition API
+
+        Args:
+            input_directory (str): JPG image files
+            output_directory (str): output from Rekognition labeler (JSON)
+        """
+
+        client = ConnectToS3(
+            aws_access_key=self._aws_access_key,
+            aws_secret_key=self._aws_secret_key).rekognition()
+
+        InvokeRekognitionLabeler(client).process(
+            input_directory=input_directory,
+            output_directory=output_directory)
+
+    def textract(self,
+                 input_directory: str,
+                 output_directory: str) -> None:
+        """ Call the AWS Textract API
+
+        Args:
+            input_directory (str): JPG image files
+            output_directory (str): output from Textract labeler (JSON)
+        """
+
+        client = ConnectToS3(
+            aws_access_key=self._aws_access_key,
+            aws_secret_key=self._aws_secret_key).textract()
+
+        InvokeTextractAPI(client).process(
+            input_directory=input_directory,
+            output_directory=output_directory)
