@@ -28,6 +28,16 @@ class FileContentWriter(BaseObject):
                 file_data: object,
                 file_path: str,
                 file_ext: str) -> None:
+        """ Write Content to File
+
+        Args:
+            file_data (object): the file data
+            file_path (str): the absolute file path
+            file_ext (str): the file extension
+
+        Raises:
+            NotImplementedError: unrecognized file extension
+        """
 
         if not file_data or not len(file_data):
             return None
