@@ -7,3 +7,5 @@ from .find_file_by_version import FindFileByVersion
 from .read_from_cache import ReadFromCache
 from .create_bucket_folder import CreateBucketFolder
 from .upload_image_files import UploadImageFiles
+from .invoke_rekognition_labeler import InvokeRekognitionLabeler
+from .invoke_textract_api import InvokeTextractAPI
