@@ -30,7 +30,7 @@ class FindLatestVersionNumber(BaseObject):
 
         Args:
             bucket_name (str): the name of the bucket
-                e.g., iceberg-data-core
+                e.g., name-of-bucket
             file_name (str): the qualified name of the file
                 e.g., 'training/myeliza/doctor'
 
